@@ -155,8 +155,9 @@ dfTrials2Long <- function(df) {
   # convert html entities
   htmlEnt <- grepl("&[#a-zA-Z]+;", out[["value"]])
   if (any(htmlEnt)) out[["value"]][htmlEnt] <-
-    sapply(out[["value"]][htmlEnt], function(i)
-      xml2::xml_text(xml2::read_html(charToRaw(i))), USE.NAMES = FALSE)
+    sapply(out[["value"]][htmlEnt], function(i) {
+      xml2::xml_text(xml2::read_html(charToRaw(i)))
+    }, USE.NAMES = FALSE)
   message(". ", appendLF = FALSE)
 
   # generate new data frame with target columns and order
