@@ -7,9 +7,17 @@ source("setup_ctrdata.R")
 if (!checkDuckdb())   exit_file("Reason: no DuckDB")
 if (!checkInternet()) exit_file("Reason: no internet connectivity")
 
-#### CTGOV ####
+#### CTIS ####
 tf <- function() {
 
+  # test
+  expect_error(
+    dbQueryHistory(
+      nodbi::src_duckdb(
+        dbdir = ":memory:")),
+    "Specify parameter"
+  )
+
   # create database object
   dbc <- suppressWarnings(nodbi::src_duckdb(
     dbdir = ":memory:",
@@ -27,9 +35,12 @@ tf <- function() {
   }, add = TRUE)
 
   # check server
-  if (httr::status_code(
-    httr::HEAD("https://euclinicaltrials.eu/",
-               httr::timeout(10L))) != 200L
+  testUrl <- "https://euclinicaltrials.eu/ctis-public/search"
+  testGet <- function() try(httr::HEAD(testUrl, httr::timeout(10L)), silent = TRUE)
+  testOnce <- testGet()
+
+  if (inherits(testOnce, "try-error") ||
+      httr::status_code(testOnce) != 200L
   ) return(exit_file("Reason: CTIS not working"))
 
   # do tests
